==> 0.0.9.tar.gz: lib/search/search_page/search_render.dart <==
import 'package:flextech/search/search_page/interfaces/i_search_tile.dart';
import 'package:flutter/material.dart';

class SearchRender extends StatelessWidget {
  final ISearchTile data;
  final Color textColor;
  final Function onTap;
  final ThemeData theme;

  const SearchRender(
      {Key key,
      @required this.data,
      @required this.textColor,
      @required this.onTap,
      @required this.theme})
      : super(key: key);
  @override
  Widget build(BuildContext context) {
    return Card(
      child: getContent(),
    );
  }

  Widget getContent() {
    if (data.title == null) {
      throw Exception("A propriedade title do ISearchTile é obrigatoria");
    }

    if (data.avatar != null) {
      if (data.subTitle != null) {
        return ListTile(
          onTap: () => this.onTap(data),
          leading: getPhoto(data.avatar),
          title: Text(
            data.title,
            style: TextStyle(color: textColor),
          ),
          subtitle: Text(
            data.subTitle,
            style: TextStyle(color: textColor),
          ),
        );
      }
      return ListTile(
        onTap: () => this.onTap(data),
        leading: getPhoto(data.avatar),
        title: Text(
          data.title,
          style: TextStyle(color: textColor),
        ),
      );
    } else {
      if (data.subTitle != null) {
        return ListTile(
          onTap: () => this.onTap(data),
          title: Text(
            data.title,
            style: TextStyle(color: textColor),
          ),
          subtitle: Text(
            data.subTitle,
            style: TextStyle(color: textColor),
          ),
        );
      }
      return ListTile(
        onTap: () => this.onTap(data),
        title: Text(
          data.title,
          style: TextStyle(color: textColor),
        ),
      );
    }
  }

  getPhoto(String url) {
    return Container(
      alignment: Alignment.center,
      width: 60,
      height: 60,
      child: Container(
        width: 60,
        height: 60,
        alignment: Alignment.center,
        decoration: BoxDecoration(
          shape: BoxShape.circle,
          gradient: LinearGradient(colors: [
            this.theme.colorScheme.primary,
            this.theme.colorScheme.secondary,
          ], begin: Alignment.topRight, end: Alignment.bottomLeft),
        ),
        child: Container(
          alignment: Alignment.center,
          width: 55,
          height: 55,
          decoration: BoxDecoration(
            image: DecorationImage(fit: BoxFit.cover, image: NetworkImage(url)),
            borderRadius: BorderRadius.all(Radius.circular((50) / 2)),
          ),
        ),
      ),
    );
  }
}

==> 0.0.17.tar.gz: lib/search/search_page/search_render.dart <==
import 'package:flextech/search/search_page/interfaces/i_search_tile.dart';
import 'package:flutter/material.dart';

class SearchRender extends StatelessWidget {
  final ISearchTile data;
  final Color textColor;
  final Function onTap;
  final ThemeData theme;

  const SearchRender(
      {Key? key,
      required this.data,
      required this.textColor,
      required this.onTap,
      required this.theme})
      : super(key: key);
  @override
  Widget build(BuildContext context) {
    return Card(
      child: getContent(),
    );
  }

  Widget getContent() {
    if (data.avatar != null) {
      if (data.subTitle != null) {
        return ListTile(
          onTap: () => this.onTap(data),
          leading: getPhoto(data.avatar!),
          title: Text(
            data.title,
            style: TextStyle(color: textColor),
          ),
          subtitle: Text(
            data.subTitle!,
            style: TextStyle(color: textColor),
          ),
        );
      }
      return ListTile(
        onTap: () => this.onTap(data),
        leading: getPhoto(data.avatar!),
        title: Text(
          data.title,
          style: TextStyle(color: textColor),
        ),
      );
    } else {
      if (data.subTitle != null) {
        return ListTile(
          onTap: () => this.onTap(data),
          title: Text(
            data.title,
            style: TextStyle(color: textColor),
          ),
          subtitle: Text(
            data.subTitle!,
            style: TextStyle(color: textColor),
          ),
        );
      }
      return ListTile(
        onTap: () => this.onTap(data),
        title: Text(
          data.title,
          style: TextStyle(color: textColor),
        ),
      );
    }
  }

  getPhoto(String url) {
    return Container(
      alignment: Alignment.center,
      width: 60,
      height: 60,
      child: Container(
        width: 60,
        height: 60,
        alignment: Alignment.center,
        decoration: BoxDecoration(
          shape: BoxShape.circle,
          gradient: LinearGradient(colors: [
            this.theme.colorScheme.primary,
            this.theme.colorScheme.secondary,
          ], begin: Alignment.topRight, end: Alignment.bottomLeft),
        ),
        child: Container(
          alignment: Alignment.center,
          width: 55,
          height: 55,
          decoration: BoxDecoration(
            image: DecorationImage(fit: BoxFit.cover, image: NetworkImage(url)),
            borderRadius: BorderRadius.all(Radius.circular((50) / 2)),
          ),
        ),
      ),
    );
  }
}
